==> kvision-server-jooby-js-5.2.0.jar: kvision-kvision-server-jooby-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-jooby-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-jooby-js-legacy'.");
    }if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-jooby-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-server-jooby-js-legacy'.");
    }root['kvision-kvision-server-jooby-js-legacy'] = factory(typeof this['kvision-kvision-server-jooby-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-server-jooby-js-legacy'], kotlin, this['kvision-kvision-common-remote-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_js_legacy) {
  'use strict';
  var KVServiceManagerJs = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceManagerJs;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceMgr;
  KVServiceManager.prototype = Object.create(KVServiceManagerJs.prototype);
  KVServiceManager.prototype.constructor = KVServiceManager;
  function KVServiceManager(serviceClass) {
    KVServiceManagerJs.call(this);
  }
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceManagerJs, KVServiceMgr]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-jooby-js-legacy', _);
  return _;
}));

==> kvision-server-jooby-js-5.10.1.jar: kvision-kvision-server-jooby-js-legacy.js <==
(function (root, factory) {
  if (typeof define === 'function' && define.amd)
    define(['exports', 'kotlin', 'kvision-kvision-common-remote-js-legacy'], factory);
  else if (typeof exports === 'object')
    factory(module.exports, require('kotlin'), require('kvision-kvision-common-remote-js-legacy'));
  else {
    if (typeof kotlin === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-jooby-js-legacy'. Its dependency 'kotlin' was not found. Please, check whether 'kotlin' is loaded prior to 'kvision-kvision-server-jooby-js-legacy'.");
    }
    if (typeof this['kvision-kvision-common-remote-js-legacy'] === 'undefined') {
      throw new Error("Error loading module 'kvision-kvision-server-jooby-js-legacy'. Its dependency 'kvision-kvision-common-remote-js-legacy' was not found. Please, check whether 'kvision-kvision-common-remote-js-legacy' is loaded prior to 'kvision-kvision-server-jooby-js-legacy'.");
    }
    root['kvision-kvision-server-jooby-js-legacy'] = factory(typeof this['kvision-kvision-server-jooby-js-legacy'] === 'undefined' ? {} : this['kvision-kvision-server-jooby-js-legacy'], kotlin, this['kvision-kvision-common-remote-js-legacy']);
  }
}(this, function (_, Kotlin, $module$kvision_kvision_common_remote_js_legacy) {
  'use strict';
  var KVServiceManagerJs = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceManagerJs;
  var Kind_CLASS = Kotlin.Kind.CLASS;
  var KVServiceMgr = $module$kvision_kvision_common_remote_js_legacy.io.kvision.remote.KVServiceMgr;
  KVServiceManager.prototype = Object.create(KVServiceManagerJs.prototype);
  KVServiceManager.prototype.constructor = KVServiceManager;
  function KVServiceManager(serviceClass) {
    KVServiceManagerJs.call(this);
  }
  KVServiceManager.$metadata$ = {
    kind: Kind_CLASS,
    simpleName: 'KVServiceManager',
    interfaces: [KVServiceManagerJs, KVServiceMgr]
  };
  var package$io = _.io || (_.io = {});
  var package$kvision = package$io.kvision || (package$io.kvision = {});
  var package$remote = package$kvision.remote || (package$kvision.remote = {});
  package$remote.KVServiceManager = KVServiceManager;
  Kotlin.defineModule('kvision-kvision-server-jooby-js-legacy', _);
  return _;
}));
